@@ -1,6 +1,7 @@
 package cluster
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"time"
@@ -15,8 +16,8 @@ import (
 )
 
 type Cluster interface {
-	Upgrade(dryRun bool) error
-	Delete(waitInterval time.Duration, wait, force, disableNodegroupEviction bool, parallel int) error
+	Upgrade(ctx context.Context, dryRun bool) error
+	Delete(ctx context.Context, waitInterval time.Duration, wait, force, disableNodegroupEviction bool, parallel int) error
 }
 
 func New(cfg *api.ClusterConfig, ctl *eks.ClusterProvider) (Cluster, error) {
