@@ -4,11 +4,14 @@ import (
 	"context"
 	"fmt"
 
+	"github.com/aws/aws-sdk-go-v2/service/ec2"
+	ec2types "github.com/aws/aws-sdk-go-v2/service/ec2/types"
+
 	"github.com/aws/aws-sdk-go/aws"
-	awsec2 "github.com/aws/aws-sdk-go/service/ec2"
 	awseks "github.com/aws/aws-sdk-go/service/eks"
 	. "github.com/onsi/ginkgo"
 	. "github.com/onsi/gomega"
+	"github.com/stretchr/testify/mock"
 
 	"github.com/weaveworks/eksctl/pkg/actions/cluster"
 	"github.com/weaveworks/eksctl/pkg/actions/cluster/fakes"
@@ -56,7 +59,7 @@ var _ = Describe("Get", func() {
 				stackManager.HasClusterStackFromListReturnsOnCall(2, false, fmt.Errorf("foo"))
 			})
 			It("returns the clusters in that region", func() {
-				clusters, err := cluster.GetClusters(context.TODO(), intialProvider, false, 100)
+				clusters, err := cluster.GetClusters(context.Background(), intialProvider, false, 100)
 				Expect(err).NotTo(HaveOccurred())
 				Expect(clusters).To(ConsistOf(
 					cluster.Description{
@@ -97,7 +100,7 @@ var _ = Describe("Get", func() {
 			})
 
 			It("errors", func() {
-				_, err := cluster.GetClusters(context.TODO(), intialProvider, false, 100)
+				_, err := cluster.GetClusters(context.Background(), intialProvider, false, 100)
 				Expect(err).To(MatchError(`failed to list cluster stacks in region "us-west-2": foo`))
 			})
 		})
@@ -111,7 +114,7 @@ var _ = Describe("Get", func() {
 			})
 
 			It("errors", func() {
-				_, err := cluster.GetClusters(context.TODO(), intialProvider, false, 100)
+				_, err := cluster.GetClusters(context.Background(), intialProvider, false, 100)
 				Expect(err).To(MatchError(`failed to list clusters in region "us-west-2": foo`))
 			})
 		})
@@ -141,8 +144,8 @@ var _ = Describe("Get", func() {
 			BeforeEach(func() {
 				awsProvider.ReturnsOnCall(0, &eks.ClusterProvider{Provider: providerRegion1}, nil)
 				awsProvider.ReturnsOnCall(1, &eks.ClusterProvider{Provider: providerRegion2}, nil)
-				intialProvider.MockEC2().On("DescribeRegions", &awsec2.DescribeRegionsInput{}).Return(&awsec2.DescribeRegionsOutput{
-					Regions: []*awsec2.Region{
+				intialProvider.MockEC2().On("DescribeRegions", mock.Anything, &ec2.DescribeRegionsInput{}).Return(&ec2.DescribeRegionsOutput{
+					Regions: []ec2types.Region{
 						{
 							RegionName: aws.String("us-west-1"),
 						},
@@ -173,7 +176,7 @@ var _ = Describe("Get", func() {
 			})
 
 			It("returns the clusters across all authorised regions", func() {
-				clusters, err := cluster.GetClusters(context.TODO(), intialProvider, true, 100)
+				clusters, err := cluster.GetClusters(context.Background(), intialProvider, true, 100)
 				Expect(err).NotTo(HaveOccurred())
 				Expect(clusters).To(ConsistOf(
 					cluster.Description{
@@ -212,11 +215,11 @@ var _ = Describe("Get", func() {
 
 		When("DescribeRegion errors", func() {
 			BeforeEach(func() {
-				intialProvider.MockEC2().On("DescribeRegions", &awsec2.DescribeRegionsInput{}).Return(nil, fmt.Errorf("foo"))
+				intialProvider.MockEC2().On("DescribeRegions", mock.Anything, &ec2.DescribeRegionsInput{}).Return(nil, fmt.Errorf("foo"))
 			})
 
 			It("errors", func() {
-				_, err := cluster.GetClusters(context.TODO(), intialProvider, true, 100)
+				_, err := cluster.GetClusters(context.Background(), intialProvider, true, 100)
 				Expect(err).To(MatchError(`failed to describe regions: foo`))
 			})
 		})
@@ -225,8 +228,8 @@ var _ = Describe("Get", func() {
 			BeforeEach(func() {
 				awsProvider.ReturnsOnCall(0, &eks.ClusterProvider{Provider: providerRegion1}, nil)
 				awsProvider.ReturnsOnCall(1, nil, fmt.Errorf("foo"))
-				intialProvider.MockEC2().On("DescribeRegions", &awsec2.DescribeRegionsInput{}).Return(&awsec2.DescribeRegionsOutput{
-					Regions: []*awsec2.Region{
+				intialProvider.MockEC2().On("DescribeRegions", mock.Anything, &ec2.DescribeRegionsInput{}).Return(&ec2.DescribeRegionsOutput{
+					Regions: []ec2types.Region{
 						{
 							RegionName: aws.String("us-west-1"),
 						},
@@ -248,7 +251,7 @@ var _ = Describe("Get", func() {
 			})
 
 			It("returns the clusters in the regions it was successful in", func() {
-				clusters, err := cluster.GetClusters(context.TODO(), intialProvider, true, 100)
+				clusters, err := cluster.GetClusters(context.Background(), intialProvider, true, 100)
 				Expect(err).NotTo(HaveOccurred())
 				Expect(clusters).To(ConsistOf(
 					cluster.Description{
