@@ -1,13 +1,17 @@
 package karpenter
 
 import (
+	"context"
 	"fmt"
 	"sort"
 
+	"github.com/aws/aws-sdk-go-v2/service/ec2"
+	ec2types "github.com/aws/aws-sdk-go-v2/service/ec2/types"
+
+	"github.com/weaveworks/eksctl/pkg/awsapi"
+
 	"github.com/aws/aws-sdk-go/aws"
 	cfn "github.com/aws/aws-sdk-go/service/cloudformation"
-	"github.com/aws/aws-sdk-go/service/ec2"
-	"github.com/aws/aws-sdk-go/service/ec2/ec2iface"
 	"github.com/kris-nova/logger"
 
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
@@ -24,30 +28,32 @@ type karpenterIAMRolesTask struct {
 	info                string
 	stackManager        manager.StackManager
 	cfg                 *api.ClusterConfig
-	ec2API              ec2iface.EC2API
+	ec2API              awsapi.EC2
+	ctx                 context.Context
 	instanceProfileName string
 }
 
 func (k *karpenterIAMRolesTask) Describe() string { return k.info }
 func (k *karpenterIAMRolesTask) Do(errs chan error) error {
-	return k.createKarpenterIAMRolesTask(errs)
+	return k.createKarpenterIAMRolesTask(k.ctx, errs)
 }
 
 // newTasksToInstallKarpenterIAMRoles defines tasks required to create Karpenter IAM roles.
-func newTasksToInstallKarpenterIAMRoles(cfg *api.ClusterConfig, stackManager manager.StackManager, ec2API ec2iface.EC2API, instanceProfileName string) *tasks.TaskTree {
+func newTasksToInstallKarpenterIAMRoles(ctx context.Context, cfg *api.ClusterConfig, stackManager manager.StackManager, ec2API awsapi.EC2, instanceProfileName string) *tasks.TaskTree {
 	taskTree := &tasks.TaskTree{Parallel: true}
 	taskTree.Append(&karpenterIAMRolesTask{
 		info:                fmt.Sprintf("create karpenter for stack %q", cfg.Metadata.Name),
 		stackManager:        stackManager,
 		cfg:                 cfg,
 		ec2API:              ec2API,
+		ctx:                 ctx,
 		instanceProfileName: instanceProfileName,
 	})
 	return taskTree
 }
 
 // createKarpenterIAMRolesTask creates Karpenter IAM Roles.
-func (k *karpenterIAMRolesTask) createKarpenterIAMRolesTask(errs chan error) error {
+func (k *karpenterIAMRolesTask) createKarpenterIAMRolesTask(ctx context.Context, errs chan error) error {
 	name := k.makeKarpenterStackName()
 
 	logger.Info("building nodegroup stack %q", name)
@@ -63,7 +69,7 @@ func (k *karpenterIAMRolesTask) createKarpenterIAMRolesTask(errs chan error) err
 		return fmt.Errorf("failed to create stack: %w", err)
 	}
 
-	return k.ensureSubnetsHaveTags()
+	return k.ensureSubnetsHaveTags(ctx)
 }
 
 // makeNodeGroupStackName generates the name of the Karpenter stack identified by its name, isolated by the cluster this StackCollection operates on
@@ -72,7 +78,7 @@ func (k *karpenterIAMRolesTask) makeKarpenterStackName() string {
 }
 
 // ensureSubnetsHaveTags sets of overwrites kubernetes.io/cluster/<name> tags on subnets with the current value.
-func (k *karpenterIAMRolesTask) ensureSubnetsHaveTags() error {
+func (k *karpenterIAMRolesTask) ensureSubnetsHaveTags(ctx context.Context) error {
 	var ids []string
 	for _, subnet := range k.cfg.VPC.Subnets.Private {
 		ids = append(ids, subnet.ID)
@@ -83,15 +89,15 @@ func (k *karpenterIAMRolesTask) ensureSubnetsHaveTags() error {
 	sort.Strings(ids)
 	clusterTag := fmt.Sprintf(kubernetesTagFormat, k.cfg.Metadata.Name)
 	creatTagsInput := &ec2.CreateTagsInput{
-		Resources: aws.StringSlice(ids),
-		Tags: []*ec2.Tag{
+		Resources: ids,
+		Tags: []ec2types.Tag{
 			{
 				Key:   aws.String(clusterTag),
 				Value: aws.String(""),
 			},
 		},
 	}
-	if _, err := k.ec2API.CreateTags(creatTagsInput); err != nil {
+	if _, err := k.ec2API.CreateTags(ctx, creatTagsInput); err != nil {
 		return fmt.Errorf("failed to add tags for subnets: %w", err)
 	}
 	return nil
