@@ -1,6 +1,7 @@
 package addons
 
 import (
+	"context"
 	"fmt"
 
 	"github.com/aws/aws-sdk-go/aws/awserr"
@@ -14,7 +15,7 @@ import (
 
 // IRSAHelper provides methods for enabling IRSA
 type IRSAHelper interface {
-	IsSupported() (bool, error)
+	IsSupported(ctx context.Context) (bool, error)
 	CreateOrUpdate(serviceAccounts *api.ClusterIAMServiceAccount) error
 }
 
@@ -37,8 +38,8 @@ func NewIRSAHelper(oidc *iamoidc.OpenIDConnectManager, stackManager manager.Stac
 }
 
 // IsSupported checks whether IRSA is supported or not
-func (h *irsaHelper) IsSupported() (bool, error) {
-	exists, err := h.oidc.CheckProviderExists()
+func (h *irsaHelper) IsSupported(ctx context.Context) (bool, error) {
+	exists, err := h.oidc.CheckProviderExists(ctx)
 	if err != nil {
 		return false, errors.Wrapf(err, "error checking OIDC provider")
 	}
