@@ -14,10 +14,10 @@ import (
 	"github.com/aws/aws-sdk-go/aws/client"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/cloudformation/cloudformationiface"
-	"github.com/aws/aws-sdk-go/service/ec2/ec2iface"
+
 	"github.com/aws/aws-sdk-go/service/eks"
 	"github.com/aws/aws-sdk-go/service/eks/eksiface"
-	"github.com/aws/aws-sdk-go/service/iam/iamiface"
+
 	"github.com/pkg/errors"
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -652,11 +652,10 @@ type ClusterProvider interface {
 	CloudFormationDisableRollback() bool
 	ASG() awsapi.ASG
 	EKS() eksiface.EKSAPI
-	EC2() ec2iface.EC2API
 	SSM() awsapi.SSM
-	IAM() iamiface.IAMAPI
 	CloudTrail() awsapi.CloudTrail
 	CloudWatchLogs() awsapi.CloudWatchLogs
+	IAM() awsapi.IAM
 	Region() string
 	Profile() string
 	WaitTimeout() time.Duration
@@ -667,6 +666,7 @@ type ClusterProvider interface {
 	ELBV2() awsapi.ELBV2
 	STS() awsapi.STS
 	STSPresigner() STSPresigner
+	EC2() awsapi.EC2
 }
 
 // STSPresigner defines the method to pre-sign GetCallerIdentity requests to add a proper header required by EKS for
