@@ -11,9 +11,7 @@ import (
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/aws-sdk-go/service/cloudformation/cloudformationiface"
-	"github.com/aws/aws-sdk-go/service/ec2/ec2iface"
 	"github.com/aws/aws-sdk-go/service/eks/eksiface"
-	"github.com/aws/aws-sdk-go/service/iam/iamiface"
 	"github.com/kris-nova/logger"
 	"github.com/pkg/errors"
 
@@ -67,17 +65,18 @@ type ChangeSet = cloudformation.DescribeChangeSetOutput
 // StackCollection stores the CloudFormation stack information
 type StackCollection struct {
 	cloudformationAPI cloudformationiface.CloudFormationAPI
-	ec2API            ec2iface.EC2API
+	ec2API            awsapi.EC2
 	eksAPI            eksiface.EKSAPI
-	iamAPI            iamiface.IAMAPI
+	iamAPI            awsapi.IAM
 	cloudTrailAPI     awsapi.CloudTrail
 	asgAPI            awsapi.ASG
-	spec              *api.ClusterConfig
-	disableRollback   bool
-	roleARN           string
-	region            string
-	waitTimeout       time.Duration
-	sharedTags        []*cloudformation.Tag
+
+	spec            *api.ClusterConfig
+	disableRollback bool
+	roleARN         string
+	region          string
+	waitTimeout     time.Duration
+	sharedTags      []*cloudformation.Tag
 }
 
 func newTag(key, value string) *cloudformation.Tag {
@@ -163,7 +162,7 @@ func (c *StackCollection) DoCreateStackRequest(i *Stack, templateData TemplateDa
 // any errors will be written to errs channel, when nil is written,
 // assume completion, do not expect more then one error value on the
 // channel, it's closed immediately after it is written to
-func (c *StackCollection) CreateStack(stackName string, resourceSet builder.ResourceSet, tags, parameters map[string]string, errs chan error) error {
+func (c *StackCollection) CreateStack(stackName string, resourceSet builder.ResourceSetReader, tags, parameters map[string]string, errs chan error) error {
 	stack, err := c.createStackRequest(stackName, resourceSet, tags, parameters)
 	if err != nil {
 		return err
@@ -174,7 +173,7 @@ func (c *StackCollection) CreateStack(stackName string, resourceSet builder.Reso
 }
 
 // createClusterStack creates the cluster stack
-func (c *StackCollection) createClusterStack(stackName string, resourceSet builder.ResourceSet, errCh chan error) error {
+func (c *StackCollection) createClusterStack(stackName string, resourceSet builder.ResourceSetReader, errCh chan error) error {
 	// Unlike with `createNodeGroupTask`, all tags are already set for the cluster stack
 	stack, err := c.createStackRequest(stackName, resourceSet, nil, nil)
 	if err != nil {
@@ -222,7 +221,7 @@ func (c *StackCollection) createClusterStack(stackName string, resourceSet build
 	return nil
 }
 
-func (c *StackCollection) createStackRequest(stackName string, resourceSet builder.ResourceSet, tags, parameters map[string]string) (*Stack, error) {
+func (c *StackCollection) createStackRequest(stackName string, resourceSet builder.ResourceSetReader, tags, parameters map[string]string) (*Stack, error) {
 	stack := &Stack{StackName: &stackName}
 	templateBody, err := resourceSet.RenderJSON()
 	if err != nil {
