@@ -86,11 +86,12 @@ func doGetCluster(cmd *cmdutils.Cmd, params *getCmdParams, listAllRegions bool)
 		logger.Writer = os.Stderr
 	}
 
+	ctx := context.TODO()
 	if cfg.Metadata.Name == "" {
-		return getAndPrinterClusters(context.TODO(), ctl, params, listAllRegions)
+		return getAndPrinterClusters(ctx, ctl, params, listAllRegions)
 	}
 
-	return getAndPrintCluster(cfg, ctl, params)
+	return getAndPrintCluster(ctx, cfg, ctl, params)
 }
 
 func getAndPrinterClusters(ctx context.Context, ctl *eks.ClusterProvider, params *getCmdParams, listAllRegions bool) error {
@@ -123,7 +124,7 @@ func addGetClustersSummaryTableColumns(printer *printers.TablePrinter) {
 	})
 }
 
-func getAndPrintCluster(cfg *api.ClusterConfig, ctl *eks.ClusterProvider, params *getCmdParams) error {
+func getAndPrintCluster(ctx context.Context, cfg *api.ClusterConfig, ctl *eks.ClusterProvider, params *getCmdParams) error {
 	printer, err := printers.NewPrinter(params.output)
 	if err != nil {
 		return err
@@ -133,7 +134,7 @@ func getAndPrintCluster(cfg *api.ClusterConfig, ctl *eks.ClusterProvider, params
 		addGetClusterSummaryTableColumns(printer.(*printers.TablePrinter))
 	}
 
-	cluster, err := ctl.GetCluster(cfg.Metadata.Name)
+	cluster, err := ctl.GetCluster(ctx, cfg.Metadata.Name)
 
 	if err != nil {
 		return err
