@@ -7,6 +7,8 @@ import (
 	"os"
 	"time"
 
+	"github.com/gofrs/flock"
+
 	"github.com/aws/aws-sdk-go-v2/credentials/stscreds"
 	"github.com/aws/aws-sdk-go-v2/service/autoscaling"
 	"github.com/aws/aws-sdk-go-v2/service/cloudtrail"
@@ -20,13 +22,10 @@ import (
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/cloudformation"
 	"github.com/aws/aws-sdk-go/service/cloudformation/cloudformationiface"
-	"github.com/aws/aws-sdk-go/service/ec2"
-	"github.com/aws/aws-sdk-go/service/ec2/ec2iface"
+
 	awseks "github.com/aws/aws-sdk-go/service/eks"
 	"github.com/aws/aws-sdk-go/service/eks/eksiface"
-	"github.com/aws/aws-sdk-go/service/iam"
-	"github.com/aws/aws-sdk-go/service/iam/iamiface"
-	"github.com/gofrs/flock"
+
 	"github.com/kris-nova/logger"
 	"github.com/pkg/errors"
 	"github.com/spf13/afero"
@@ -58,7 +57,7 @@ type ClusterProvider struct {
 type KubeProvider interface {
 	NewRawClient(spec *api.ClusterConfig) (*kubewrapper.RawClient, error)
 	ServerVersion(rawClient *kubernetes.RawClient) (string, error)
-	LoadClusterIntoSpecFromStack(spec *api.ClusterConfig, stackManager manager.StackManager) error
+	LoadClusterIntoSpecFromStack(ctx context.Context, spec *api.ClusterConfig, stackManager manager.StackManager) error
 	ValidateClusterForCompatibility(cfg *api.ClusterConfig, stackManager manager.StackManager) error
 	UpdateAuthConfigMap(nodeGroups []*api.NodeGroup, clientSet kubernetes.Interface) error
 	WaitForNodes(clientSet kubernetes.Interface, ng KubeNodeGroup) error
@@ -67,16 +66,13 @@ type KubeProvider interface {
 // ProviderServices stores the used APIs
 type ProviderServices struct {
 	spec *api.ProviderConfig
-	cfn  cloudformationiface.CloudFormationAPI
 	asg  awsapi.ASG
 	eks  eksiface.EKSAPI
-	ec2  ec2iface.EC2API
-	iam  iamiface.IAMAPI
+	cfn  cloudformationiface.CloudFormationAPI
 
 	cloudtrail     awsapi.CloudTrail
 	cloudwatchlogs awsapi.CloudWatchLogs
-
-	session *session.Session
+	session        *session.Session
 
 	*ServicesV2
 }
@@ -98,12 +94,6 @@ func (p ProviderServices) ASG() awsapi.ASG { return p.asg }
 // EKS returns a representation of the EKS API
 func (p ProviderServices) EKS() eksiface.EKSAPI { return p.eks }
 
-// EC2 returns a representation of the EC2 API
-func (p ProviderServices) EC2() ec2iface.EC2API { return p.ec2 }
-
-// IAM returns a representation of the IAM API
-func (p ProviderServices) IAM() iamiface.IAMAPI { return p.iam }
-
 // CloudTrail returns a representation of the CloudTrail API
 func (p ProviderServices) CloudTrail() awsapi.CloudTrail { return p.cloudtrail }
 
@@ -178,8 +168,6 @@ func New(ctx context.Context, spec *api.ProviderConfig, clusterSpec *api.Cluster
 	provider.session = s
 	provider.cfn = cloudformation.New(s)
 	provider.eks = awseks.New(s)
-	provider.ec2 = ec2.New(s)
-	provider.iam = iam.New(s)
 
 	cfg, err := newV2Config(spec, c.Provider.Region(), credentialsCacheFilePath)
 	if err != nil {
@@ -207,14 +195,7 @@ func New(ctx context.Context, spec *api.ProviderConfig, clusterSpec *api.Cluster
 		logger.Debug("Setting EKS endpoint to %s", endpoint)
 		provider.eks = awseks.New(s, s.Config.Copy().WithEndpoint(endpoint))
 	}
-	if endpoint, ok := os.LookupEnv("AWS_EC2_ENDPOINT"); ok {
-		logger.Debug("Setting EC2 endpoint to %s", endpoint)
-		provider.ec2 = ec2.New(s, s.Config.Copy().WithEndpoint(endpoint))
-	}
-	if endpoint, ok := os.LookupEnv("AWS_IAM_ENDPOINT"); ok {
-		logger.Debug("Setting IAM endpoint to %s", endpoint)
-		provider.iam = iam.New(s, s.Config.Copy().WithEndpoint(endpoint))
-	}
+
 	if endpoint, ok := os.LookupEnv("AWS_CLOUDTRAIL_ENDPOINT"); ok {
 		logger.Debug("Setting CloudTrail endpoint to %s", endpoint)
 		provider.cloudtrail = cloudtrail.NewFromConfig(cfg, func(o *cloudtrail.Options) {
@@ -341,7 +322,7 @@ func ResolveAMI(ctx context.Context, provider api.ClusterProvider, version strin
 }
 
 // SetAvailabilityZones sets the given (or chooses) the availability zones
-func SetAvailabilityZones(spec *api.ClusterConfig, given []string, ec2 ec2iface.EC2API, region string) error {
+func SetAvailabilityZones(ctx context.Context, spec *api.ClusterConfig, given []string, ec2API awsapi.EC2, region string) error {
 	if count := len(given); count != 0 {
 		if count < api.MinRequiredAvailabilityZones {
 			return api.ErrTooFewAvailabilityZones(given)
@@ -358,7 +339,7 @@ func SetAvailabilityZones(spec *api.ClusterConfig, given []string, ec2 ec2iface.
 	}
 
 	logger.Debug("determining availability zones")
-	zones, err := az.GetAvailabilityZones(ec2, region)
+	zones, err := az.GetAvailabilityZones(ctx, ec2API, region)
 	if err != nil {
 		return errors.Wrap(err, "getting availability zones")
 	}
