@@ -3,11 +3,14 @@ package eks
 import (
 	"sync"
 
+	"github.com/aws/aws-sdk-go-v2/service/ec2"
+
 	"github.com/aws/aws-sdk-go-v2/aws"
 	"github.com/aws/aws-sdk-go-v2/aws/retry"
 	"github.com/aws/aws-sdk-go-v2/service/cloudformation"
 	"github.com/aws/aws-sdk-go-v2/service/elasticloadbalancing"
 	"github.com/aws/aws-sdk-go-v2/service/elasticloadbalancingv2"
+	"github.com/aws/aws-sdk-go-v2/service/iam"
 	"github.com/aws/aws-sdk-go-v2/service/ssm"
 	"github.com/aws/aws-sdk-go-v2/service/sts"
 
@@ -29,6 +32,8 @@ type ServicesV2 struct {
 	elasticloadbalancing   *elasticloadbalancing.Client
 	elasticloadbalancingV2 *elasticloadbalancingv2.Client
 	ssm                    *ssm.Client
+	iam                    *iam.Client
+	ec2                    *ec2.Client
 }
 
 // STS implements the AWS STS service.
@@ -110,3 +115,23 @@ func (s *ServicesV2) SSM() awsapi.SSM {
 	}
 	return s.ssm
 }
+
+// IAM implements the AWS IAM service.
+func (s *ServicesV2) IAM() awsapi.IAM {
+	s.mu.Lock()
+	defer s.mu.Unlock()
+	if s.iam == nil {
+		s.iam = iam.NewFromConfig(s.config)
+	}
+	return s.iam
+}
+
+// EC2 implements the AWS EC2 service.
+func (s *ServicesV2) EC2() awsapi.EC2 {
+	s.mu.Lock()
+	defer s.mu.Unlock()
+	if s.ec2 == nil {
+		s.ec2 = ec2.NewFromConfig(s.config)
+	}
+	return s.ec2
+}
